@@ -1,6 +1,8 @@
+#[cfg_attr(target_os = "netbsd", allow(unused_imports))]
 pub use self::cell::{DisplayWidth, TextCell, TextCellContents};
 pub use self::escape::escape;
 
+pub mod color_scale;
 pub mod details;
 pub mod file_name;
 pub mod grid;
